==> dojo-1.9.4.tgz: package/cldr/nls/en/generic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"field-weekday": "Day of the Week",
	"dateFormatItem-GyMMMEd": "E, MMM d, y G",
	"dateFormatItem-MMMEd": "E, MMM d",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"dateFormat-long": "MMMM d, y G",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1}, {0}",
	"dateFormat-full": "EEEE, MMMM d, y G",
	"dateFormatItem-yyyyMEd": "E, M/d/y GGGGG",
	"dateFormatItem-Md": "M/d",
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-era": "Era",
	"field-year": "Year",
	"dateTimeFormats-appendItem-Era": "{0} {1}",
	"field-hour": "Hour",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-day-relative+0": "Today",
	"field-day-relative+1": "Tomorrow",
	"dateFormatItem-GyMMMd": "MMM d, y G",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, MMM d, y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "MMM d, y G",
	"dateFormatItem-Hm": "HH:mm",
	"field-minute": "Minute",
	"field-dayperiod": "AM/PM",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "Yesterday",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} 'at' {0}",
	"dateFormatItem-MMMd": "MMM d",
	"dateFormatItem-MEd": "E, M/d",
	"dateTimeFormat-full": "{1} 'at' {0}",
	"field-day": "Day",
	"field-zone": "Time Zone",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "Last year",
	"field-month-relative+-1": "Last month",
	"dateFormatItem-hm": "h:mm a",
	"dateTimeFormats-appendItem-Year": "{0} {1}",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateFormatItem-yyyyMd": "M/d/y GGGGG",
	"field-month": "Month",
	"dateFormatItem-MMM": "LLL",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"dateFormatItem-EHm": "E HH:mm",
	"dateFormat-short": "M/d/y GGGGG",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "Second",
	"field-month-relative+0": "This month",
	"field-month-relative+1": "Next month",
	"dateFormatItem-Ed": "d E",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Week",
	"dateFormat-medium": "MMM d, y G",
	"field-year-relative+0": "This year",
	"field-week-relative+-1": "Last week",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-year-relative+1": "Next year",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "This week",
	"field-week-relative+1": "Next week"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/en/generic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"field-second-relative+0": "now",
	"field-weekday": "Day of the Week",
	"field-wed-relative+0": "this Wednesday",
	"dateFormatItem-GyMMMEd": "E, MMM d, y G",
	"dateFormatItem-MMMEd": "E, MMM d",
	"field-wed-relative+1": "next Wednesday",
	"field-tue-relative+-1": "last Tuesday",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"dateFormat-long": "MMMM d, y G",
	"field-fri-relative+-1": "last Friday",
	"field-wed-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1}, {0}",
	"dateFormat-full": "EEEE, MMMM d, y G",
	"dateFormatItem-yyyyMEd": "E, M/d/y GGGGG",
	"field-thu-relative+-1": "last Thursday",
	"dateFormatItem-Md": "M/d",
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-era": "Era",
	"field-year": "Year",
	"dateTimeFormats-appendItem-Era": "{0} {1}",
	"field-hour": "Hour",
	"field-sat-relative+0": "this Saturday",
	"field-sat-relative+1": "next Saturday",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-thu-relative+0": "this Thursday",
	"dateFormatItem-GyMMMd": "MMM d, y G",
	"field-thu-relative+1": "next Thursday",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, MMM d, y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "MMM d, y G",
	"field-sun-relative+0": "this Sunday",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "next Sunday",
	"field-minute": "Minute",
	"field-dayperiod": "am/pm",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "yesterday",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} 'at' {0}",
	"dateFormatItem-MMMd": "MMM d",
	"dateFormatItem-MEd": "E, M/d",
	"dateTimeFormat-full": "{1} 'at' {0}",
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"field-day": "Day",
	"field-zone": "Time Zone",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "last year",
	"field-month-relative+-1": "last month",
	"dateFormatItem-hm": "h:mm a",
	"dateTimeFormats-appendItem-Year": "{0} {1}",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateFormatItem-yyyyMd": "M/d/y GGGGG",
	"field-month": "Month",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "this Tuesday",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-tue-relative+1": "next Tuesday",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "this Monday",
	"field-mon-relative+1": "next Monday",
	"dateFormat-short": "M/d/y GGGGG",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "Second",
	"field-sat-relative+-1": "last Saturday",
	"field-sun-relative+-1": "last Sunday",
	"field-month-relative+0": "this month",
	"field-month-relative+1": "next month",
	"dateFormatItem-Ed": "d E",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Week",
	"dateFormat-medium": "MMM d, y G",
	"field-year-relative+0": "this year",
	"field-week-relative+-1": "last week",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-year-relative+1": "next year",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "last Monday",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "this week",
	"field-week-relative+1": "next week"
}
//end v1.x content
);
